// Test_rcTime v1.2
// This program will test the discharge time of a CAP for each port.
// It will compare each value for Min & Max, display the discharge time results
// and indentify any ranges past the Min & Max
// The TargetMin & TargetMax values were determined by using a known working stamp
// These values were added to +/-2 and loaded in the Target Max/Min varaibles
//
// When a Pin is bad by cut trace, etc.  The result will be: -1
// When a Pin goes to ground the result will be: 1
//
// Here is how the circut needs to be wired for this test to work properly
// Have each I/O pin go thru a 10k resistor, then go thru a 0.1uF cap.
// All the caps are tied together.  Allthe resistors can be in a bank which goes to a
// common ground.  Best to solder the conenctions on an app mod board to insure stability.
//
// After the test is completed the TerminalTest program will be displayed as default
// no need to re-load this program.  rcTime test still available if you enter 'jtest'
// in the TerminalTest input window.
//
// Written By: Steve Dill
// 5/15/02 Version 1.0 rcTime Test
// 5/17/02 Version 1.1 Incorporated TerminalTest.java
// 5/20/02 Version 1.2 Added clearer failed display

import stamp.core.*;

public class J_test {
  final static char CLS       = '\u0010';
  final static int TargetMin  = -1;    // Target Min = 71 - 20% = 56
  final static int TargetMax  = 95;    // Target Max = 79 + 20% = 95
  final static int Loop       = 10;    // Number of time test is performed
  static int ActualMax = -1;           // Max aquired from test
  static int ActualMin = 999;          // Min aquired from test
  static int BadMinMax = 0;            // Above/Below our Min/Max range
  static int dischargeTime;
  static int chargeTime;

  static void rcTime() {
    // Print header line
    System.out.println(CLS);
    System.out.println("     ----------------------------Pins------------------------------");
    System.out.println("Loop 00--01--02--03--04--05--06--07--08--09--10--11--12--13--14--15");

    // Calculate Results
    for (int j=1;j<=Loop;j++){
      // Print out loop#
      System.out.print("\n ");
      System.out.print(j);
      System.out.print(" ");
      if (j < 10) System.out.print(" ");

      // Charge the CAP, let it go, grab time to discharge & display it
      for (int i=0;i<=15;i++){
        CPU.writePin(CPU.pins[i],true);                     // give CAP +5v
        CPU.delay(100);                                      // wait 'till charged
        dischargeTime = CPU.rcTime(10000,CPU.pins[i],false);// time the discharge
        if (dischargeTime > ActualMax) ActualMax = dischargeTime;
        if (dischargeTime < ActualMin) ActualMin = dischargeTime;

        // Test if out of range
        if ((dischargeTime < TargetMin) || (dischargeTime > TargetMax)) {
          BadMinMax++;
          System.out.print("<");
          System.out.print(String.valueOf(dischargeTime));
          System.out.print(">");
        }//end if out of range
        else {
          System.out.print(" ");
          System.out.print(String.valueOf(dischargeTime));
          System.out.print(" ");
        }//end else in range
      }//end for i
      CPU.delay(100);
    }//end for j

    // Print Test Results
    System.out.print("\n\nNumber of Iterations: ");
    System.out.println(Loop);

    System.out.print("\nTarget Maximum: ");
    System.out.print(TargetMax);
    System.out.print("          Actual Max: ");
    System.out.println(ActualMax);

    System.out.print("Target Minumum: ");
    System.out.print(TargetMin);
    System.out.print("          Actual Min: ");
    System.out.println(ActualMin);
    System.out.println("\n");

    //Did Test Pass/Fail?
    if (BadMinMax != 0) {
      System.out.println(" ######    ##       #    #       ######  ##### ");
      System.out.println(" #        #  #      #    #       #       #    #");
      System.out.println(" #####   #    #     #    #       #####   #    #");
      System.out.println(" #       ######     #    #       #       #    #");
      System.out.println(" #       #    #     #    #       #       #    #");
      System.out.println(" #       #    #     #    ######  ######  ##### ");
      System.out.print("\nThere have been ");
      System.out.print(BadMinMax);
      System.out.println(" values out of range.");
      if (ActualMin == -1) System.out.println("A bad pin has been detected!!");
      if (ActualMin ==  1) System.out.println("A pin has gone to ground!!");
      System.out.println("\nTest: FAILED       *** WARNING ***");
    }
    else System.out.println("Test: PASSED\n");
  }//end rcTime





  public static void main() {
    // Test to see if test has been ran before, if not then run test
    int r;
 //   r = EEPROM.read(0);
   // if (r!=142) {
   //   EEPROM.write(0,(byte)(142));
      rcTime();
   //   if (r!=255) System.out.println("ATTENTION: EEPROM Mem Location 0, has been previously written to!");
   // }//r!=255

    //Test to see if test has ran before, if it has run the customers default program
  //  if (r==142) TerminalTest();

    }//end main
 }//end class